@@ -15,4 +15,4 @@ DAILY_FORECAST_URI = 'forecast/daily'
 STATION_WEATHER_HISTORY_URI = 'history/station'
 ONE_CALL_URI = 'onecall'
 ONE_CALL_HISTORICAL_URI = ONE_CALL_URI + '/timemachine'
-ICONS_BASE_URI = 'http://openweathermap.org/img/w/%s.png'
+ICONS_BASE_URI = 'http://openweathermap.org/img/wn/%s%s.png'
